@@ -38,7 +38,8 @@ import sys
 
 from mopytools.util import (timeout, get_options, step, get_channel,
                             update_cmd, is_meta_project, PYTHON, run, PIP,
-                            REPO_ROOT, has_changes, is_git)
+                            REPO_ROOT, has_changes, is_git, get_non_pinned,
+                            DependencyError)
 from mopytools.build import get_environ_info, updating_repo
 
 
@@ -118,7 +119,7 @@ def build_dep(dep=None, deps_dir=None, channel='prod', specific_tags=False,
     else:
         repo = dep
 
-    target = os.path.join(deps_dir, dep)
+    target = os.path.join(deps_dir, os.path.basename(dep))
     if os.path.exists(target):
         os.chdir(target)
         if is_git():
@@ -136,10 +137,11 @@ def build_dep(dep=None, deps_dir=None, channel='prod', specific_tags=False,
 
     if has_changes(timeout, verbose):
         if channel != 'dev':
-            print('the code was changed, aborting!')
+            print('The code was changed, aborting !')
+            print('Use the dev channel if you change locally the code')
             sys.exit(0)
         else:
-            print('Warning: the code was changed/')
+            print('Warning: the code was changed.')
 
     cmd = update_cmd(dep, channel, specific_tags)
     run(cmd, timeout, verbose)
@@ -172,6 +174,13 @@ def build_external_deps(channel, index, extras, timeout=300, verbose=False,
     if not os.path.exists(reqname):
         return
 
+    # if not dev, check for pinned versions.
+    if channel != 'dev':
+        non_pinned = get_non_pinned(reqname)
+        if len(non_pinned) > 0:
+            deps = ', '.join(non_pinned)
+            raise DependencyError('Unpinned dependencies: %s' % deps)
+
     if os.path.exists('build'):
         root = 'build'
         inc = 1
