@@ -40,7 +40,8 @@ import subprocess
 
 from mopytools.util import (timeout, get_options, step, get_channel,
                             split_version, get_spec_file, run,
-                            PYTHON, PYPI2RPM, PYPI, has_changes)
+                            PYTHON, PYPI2RPM, PYPI, has_changes,
+                            get_non_pinned, DependencyError)
 from mopytools.build import get_environ_info, updating_repo
 from mopytools.build_app import main as build_app
 
@@ -111,7 +112,8 @@ _PYTHON = 'python%d%d' % (_MAJOR, _MINOR)
 
 def _build_rpm(channel, options):
     if has_changes() and channel != 'dev' and not options.force:
-        print('the code was changed, aborting!')
+        print('The code was changed, aborting !')
+        print('Use the dev channel if you change locally the code')
         sys.exit(0)
 
     # removing any build dir
@@ -156,7 +158,7 @@ def build_core_rpm(deps, channel, specific_tags, options):
 
 @step("Building %(dep)s")
 def build_dep_rpm(dep='', deps_dir='deps', channel='prod', options=None):
-    target = os.path.join(deps_dir, dep)
+    target = os.path.join(deps_dir, os.path.basename(dep))
     if not os.path.exists(target):
         print('You need to build your deps first.')
     os.chdir(target)
@@ -205,6 +207,13 @@ def build_external_deps_rpms(channel, options):
         print("Can't find the req file for the %s channel." % channel)
         sys.exit(0)
 
+    # if not dev, check for pinned versions.
+    if channel != 'dev':
+        non_pinned = get_non_pinned(req_file)
+        if len(non_pinned) > 0:
+            deps = ', '.join(non_pinned)
+            raise DependencyError('Unpinned dependencies: %s' % deps)
+
     # we have a requirement file, we can go ahead and feed pypi2rpm with it
     with open(req_file) as f:
         for line in f.readlines():
