@@ -50,6 +50,8 @@ from distutils2.version import (NormalizedVersion, IrrationalVersionError,
 from distutils2.index.simple import Crawler, DEFAULT_SIMPLE_INDEX_URL
 from pkg_resources import parse_version
 
+from pip.req import parse_requirements
+
 
 REPO_ROOT = 'https://hg.mozilla.org/services/'
 PYTHON = sys.executable
@@ -86,7 +88,7 @@ def _sort_tags(tags):
 
 def _get_tags(prefix=TAG_PREFIX):
     if is_git():
-        cmds = ['git tag']
+        cmds = ['git tag', 'git branch']
     else:
         cmds = ['hg tags', 'hg branches']
 
@@ -101,11 +103,13 @@ def _get_tags(prefix=TAG_PREFIX):
     if output == '':
         return []
 
-    tags = [tag_ for tag_ in
-                [line.split()[0] for line in
-                 output.split('\n')]
-            if tag_.startswith(prefix)]
-
+    tags = []
+    for line in output.split('\n'):
+        tag = line.split()[0]
+        tag = tag.lstrip('*')
+        tag = tag.strip()
+        if tag.startswith(prefix):
+            tags.append(tag)
     _sort_tags(tags)
     return tags
 
@@ -231,12 +235,13 @@ def run(command, timeout=300, verbose=False, allow_exit=False):
 
 
 def envname(name):
-    return name.upper().replace('-', '_')
+    return os.path.basename(name).upper().replace('-', '_')
 
 
 def has_changes(timeout=5, verbose=False):
     if is_git():
-        code, out, err = run('git diff --exit-code', timeout, verbose, allow_exit=True)
+        code, out, err = run('git diff --exit-code', timeout, verbose,
+                             allow_exit=True)
         return code == 1
     else:
         code, out, err = run('hg diff', timeout, verbose)
@@ -276,7 +281,10 @@ def update_cmd(project=None, channel="prod", specific_tag=False,
                 print('Unknown tag or revision: %s' % rev)
                 sys.exit(1)
 
-            return '%s -r "%s"' % (cmd, rev)
+            if is_git():
+                return '%s "%s"' % (cmd, rev)
+            else:
+                return '%s -r "%s"' % (cmd, rev)
 
     return cmd
 
@@ -542,3 +550,23 @@ def get_last_channel():
         return 'prod'
     with open('.channel') as f:
         return f.read()
+
+
+class DependencyError(Exception):
+    pass
+
+
+class Options:
+    skip_requirements_regex = False
+
+
+def get_non_pinned(reqfile):
+    """Return non-pinned or dev versions.
+
+    Look for XXX==XXX patterns
+    """
+    res = []
+    for req in parse_requirements(reqfile, options=Options()):
+        if list(req.absolute_versions) == []:
+            res.append(req.name)
+    return res
